@@ -2,27 +2,21 @@ package Test::Database::Driver::CSV;
 use strict;
 use warnings;
 
-use File::Spec;
-use File::Path;
-
 use Test::Database::Driver;
 our @ISA = qw( Test::Database::Driver );
 
-sub is_filebased {1}
+use File::Spec;
+use File::Path;
 
-sub _version { return Text::CSV_XS->VERSION; }
+sub create_database {
+    my ( $class, $dbname ) = @_;
 
-sub dsn {
-    my ( $self, $dbname ) = @_;
-    my $dbdir = File::Spec->catdir( $self->base_dir(), $dbname );
-    mkpath( [$dbdir] );
-    return "dbi:CSV:f_dir=$dbdir";
-}
+    my $dbdir = File::Spec->catdir( $class->base_dir(), $dbname );
+    mkpath $dbdir if ! -e $dbdir;
 
-sub drop_database {
-    my ( $self, $dbname ) = @_;
-    my $dbdir = File::Spec->catdir( $self->base_dir(), $dbname );
-    rmtree( [$dbdir] );
+    return Test::Database::Handle->new(
+        dsn      => "dbi:CSV:f_dir=$dbdir",
+    );
 }
 
 'CSV';
@@ -52,7 +46,7 @@ Philippe Bruhat (BooK), C<< <book@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright 2008-2009 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2008 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
